@@ -20,11 +20,19 @@ from .loss import *
 
 
 class VAE(nn.Module):
+    """
+    VAE framework
+    """
     def __init__(self, enc, dec, n_domain=1):
         """
-        enc: encoder structure config
-        dec: decoder structure config
-        n_domain: number of different domains
+        Parameters
+        ----------
+        enc
+            Encoder structure config
+        dec
+            Decoder structure config
+        n_domain
+            The number of different domains
         """
         super().__init__()
         x_dim = dec[-1][1]
@@ -36,6 +44,13 @@ class VAE(nn.Module):
         self.z_dim = z_dim
     
     def load_model(self, path):
+        """
+        Load trained model parameters dictionary.
+        Parameters
+        ----------
+        path
+            file path that stores the model parameters
+        """
         pretrained_dict = torch.load(path, map_location=lambda storage, loc: storage)                            
         model_dict = self.state_dict()
         pretrained_dict = {k: v for k, v in pretrained_dict.items() if k in model_dict}
@@ -50,7 +65,29 @@ class VAE(nn.Module):
             batch_id=None,
             return_idx=False, 
             eval=False
-    ):
+        ):
+        """
+        Inference
+        
+        Parameters
+        ----------
+        dataloader
+            An iterable over the given dataset for inference.
+        device
+            'cuda' or 'cpu' for . Default: 'cuda'.
+        out
+            The inference layer for output. If 'latent', output latent feature z. If 'impute', output imputed gene expression matrix. Default: 'latent'. 
+        batch_id
+            If None, use batch 0 decoder to infer for all samples. Else, use the corresponding decoder according to the sample batch id to infer for each sample.
+        return_idx
+            Whether return the dataloader sample index. Default: False.
+        eval
+            If True, set the model to evaluation mode. If False, set the model to train mode. Default: False.
+        
+        Returns
+        -------
+        Inference layer and sample index (if return_idx=True).
+        """
         self.to(device)
         if eval:
             self.eval()
@@ -84,7 +121,6 @@ class VAE(nn.Module):
     def fit(
             self, 
             dataloader, 
-            testloader=None,
             lr=2e-4,
             max_iteration=30000,
             beta=0.5,
@@ -94,6 +130,23 @@ class VAE(nn.Module):
         ):
         """
         Fit model
+        
+        Parameters
+        ----------
+        dataloader
+            An iterable over the given dataset for training.
+        lr
+            Learning rate. Default: 2e-4.
+        max_iteration
+            Max iterations for training. Training one batch_size samples is one iteration. Default: 30000.
+        beta
+            The co-efficient of KL-divergence when calculate loss. Default: 0.5.
+        early_stopping
+            EarlyStopping class (definite in utils.py) for stoping the training if loss doesn't improve after a given patience. Default: None.
+        device
+            'cuda' or 'cpu' for training. Default: 'cuda'.
+        verbose
+            Verbosity, True or False. Default: False.
         """
         self.to(device)
         optim = torch.optim.Adam(self.parameters(), lr=lr, weight_decay=5e-4)
